@@ -1,5 +1,6 @@
 from autoarray.plot import plotters
 from autoarray.plot import inversion_plots, mat_objs
+import numpy as np
 
 
 @plotters.set_include_and_sub_plotter
@@ -135,7 +136,7 @@ def visibilities(fit, include=None, plotter=None):
     origin : True
         If true, the origin of the datas's coordinate system is plotted as a 'x'.
     """
-    plotter.plot_grid(grid=fit.visibilities)
+    plotter.plot_grid(grid=fit.visibilities.in_grid)
 
 
 @plotters.set_include_and_plotter
@@ -152,7 +153,7 @@ def noise_map(fit, include=None, plotter=None):
     origin : True
         If true, the origin of the datas's coordinate system is plotted as a 'x'.
     """
-    plotter.plot_grid(grid=fit.visibilities, color_array=fit.noise_map[:, 0])
+    plotter.plot_grid(grid=fit.visibilities.in_grid, color_array=np.real(fit.noise_map))
 
 
 @plotters.set_include_and_plotter
@@ -169,7 +170,9 @@ def signal_to_noise_map(fit, include=None, plotter=None):
     origin : True
     If true, the origin of the datas's coordinate system is plotted as a 'x'.
     """
-    plotter.plot_grid(grid=fit.visibilities, color_array=fit.signal_to_noise_map[:, 0])
+    plotter.plot_grid(
+        grid=fit.visibilities.in_grid, color_array=fit.signal_to_noise_map.real
+    )
 
 
 @plotters.set_include_and_plotter
@@ -186,7 +189,7 @@ def model_visibilities(fit, include=None, plotter=None):
     visibilities_index : int
         The index of the datas in the datas-set of which the model visibilities is plotted.
     """
-    plotter.plot_grid(grid=fit.visibilities)
+    plotter.plot_grid(grid=fit.visibilities.in_grid)
 
 
 @plotters.set_include_and_plotter
@@ -212,13 +215,13 @@ def residual_map_vs_uv_distances(
     """
 
     if plot_real:
-        y = fit.residual_map[:, 0]
+        y = np.real(fit.residual_map)
         plotter = plotter.plotter_with_new_labels(title=plotter.labels.title + " Real")
         plotter = plotter.plotter_with_new_output(
             filename=plotter.output.filename + "_real"
         )
     else:
-        y = fit.residual_map[:, 1]
+        y = np.imag(fit.residual_map)
         plotter = plotter.plotter_with_new_labels(title=plotter.labels.title + " Imag")
         plotter = plotter.plotter_with_new_output(
             filename=plotter.output.filename + "_imag"
@@ -254,13 +257,13 @@ def normalized_residual_map_vs_uv_distances(
     """
 
     if plot_real:
-        y = fit.residual_map[:, 0]
+        y = np.real(fit.residual_map)
         plotter = plotter.plotter_with_new_labels(title=plotter.labels.title + " Real")
         plotter = plotter.plotter_with_new_output(
             filename=plotter.output.filename + "_real"
         )
     else:
-        y = fit.residual_map[:, 1]
+        y = np.imag(fit.residual_map)
         plotter = plotter.plotter_with_new_labels(title=plotter.labels.title + " Imag")
         plotter = plotter.plotter_with_new_output(
             filename=plotter.output.filename + "_imag"
@@ -296,13 +299,13 @@ def chi_squared_map_vs_uv_distances(
     """
 
     if plot_real:
-        y = fit.residual_map[:, 0]
+        y = np.real(fit.residual_map)
         plotter = plotter.plotter_with_new_labels(title=plotter.labels.title + " Real")
         plotter = plotter.plotter_with_new_output(
             filename=plotter.output.filename + "_real"
         )
     else:
-        y = fit.residual_map[:, 1]
+        y = np.imag(fit.residual_map)
         plotter = plotter.plotter_with_new_labels(title=plotter.labels.title + " Imag")
         plotter = plotter.plotter_with_new_output(
             filename=plotter.output.filename + "_imag"
