@@ -639,18 +639,14 @@ class TestRectangularMapper:
             grid=sub_grid_7x7, pixelization_grid=rectangular_pixelization_grid
         )
 
-        image_pixel_indexes = (
-            rectangular_mapper.image_pixel_indexes_from_source_pixel_indexes(
-                source_pixel_indexes=[0, 1]
-            )
+        image_pixel_indexes = rectangular_mapper.image_pixel_indexes_from_source_pixel_indexes(
+            source_pixel_indexes=[0, 1]
         )
 
         assert image_pixel_indexes == [0, 1, 2, 3, 4, 5, 6, 7]
 
-        image_pixel_indexes = (
-            rectangular_mapper.image_pixel_indexes_from_source_pixel_indexes(
-                source_pixel_indexes=[[0], [4]]
-            )
+        image_pixel_indexes = rectangular_mapper.image_pixel_indexes_from_source_pixel_indexes(
+            source_pixel_indexes=[[0], [4]]
         )
 
         assert image_pixel_indexes == [[0, 1, 2, 3], [16, 17, 18, 19]]
