@@ -1,11 +1,7 @@
-import os
-
 import numpy as np
 
 import autoarray as aa
 
-test_data_dir = "{}/files/mask/".format(os.path.dirname(os.path.realpath(__file__)))
-
 
 class TestSubQuantities:
     def test__sub_pixels_in_mask_is_pixels_in_mask_times_sub_size_squared(self):
