@@ -13,16 +13,36 @@ test_data_dir = path.join(
 
 
 class TestVisibilitiesAPI:
-    def test__manuual__makes_visibilities_without_other_inputs(self):
+    def test__manual__makes_visibilities_without_other_inputs(self):
+
+        visibilities = aa.Visibilities.manual_1d(visibilities=[1.0 + 2.0j, 3.0 + 4.0j])
+
+        assert type(visibilities) == vis.Visibilities
+        assert (visibilities.in_1d == np.array([1.0 + 2.0j, 3.0 + 4.0j])).all()
+        assert (visibilities.in_array == np.array([[1.0, 2.0], [3.0, 4.0]])).all()
+        assert (visibilities.amplitudes == np.array([np.sqrt(5), 5.0])).all()
+        assert visibilities.phases == pytest.approx(
+            np.array([1.10714872, 0.92729522]), 1.0e-4
+        )
+
+        visibilities = aa.Visibilities.manual_1d(
+            visibilities=[1.0 + 2.0j, 3.0 + 4.0j, 5.0 + 6.0j]
+        )
+
+        assert type(visibilities) == vis.Visibilities
+        assert (
+            visibilities.in_1d == np.array([1.0 + 2.0j, 3.0 + 4.0j, 5.0 + 6.0j])
+        ).all()
+        assert (
+            visibilities.in_array == np.array([[1.0, 2.0], [3.0, 4.0], [5.0, 6.0]])
+        ).all()
+
+    def test__manual__makes_visibilities_with_converted_input_as_list(self):
 
         visibilities = aa.Visibilities.manual_1d(visibilities=[[1.0, 2.0], [3.0, 4.0]])
 
         assert type(visibilities) == vis.Visibilities
-        assert visibilities.in_1d_flipped == np.array([[2.0, 1.0], [4.0, 3.0]])
-        assert (visibilities.in_1d == np.array([[1.0, 2.0], [3.0, 4.0]])).all()
-        assert (visibilities.real == np.array([1.0, 3.0])).all()
-        assert (visibilities.imag == np.array([2.0, 4.0])).all()
-        assert (visibilities.as_complex == np.array([[1.0 + 2.0j], [3.0 + 4.0j]])).all()
+        assert (visibilities.in_1d == np.array([1.0 + 2.0j, 3.0 + 4.0j])).all()
         assert (visibilities.amplitudes == np.array([np.sqrt(5), 5.0])).all()
         assert visibilities.phases == pytest.approx(
             np.array([1.10714872, 0.92729522]), 1.0e-4
@@ -34,13 +54,7 @@ class TestVisibilitiesAPI:
 
         assert type(visibilities) == vis.Visibilities
         assert (
-            visibilities.in_1d == np.array([[1.0, 2.0], [3.0, 4.0], [5.0, 6.0]])
-        ).all()
-        assert (visibilities.real == np.array([1.0, 3.0, 5.0])).all()
-        assert (visibilities.imag == np.array([2.0, 4.0, 6.0])).all()
-        assert (
-            visibilities.as_complex
-            == np.array([[1.0 + 2.0j], [3.0 + 4.0j], [5.0 + 6.0j]])
+            visibilities.in_1d == np.array([1.0 + 2.0j, 3.0 + 4.0j, 5.0 + 6.0j])
         ).all()
 
     def test__full__makes_visibilities_without_other_inputs(self):
@@ -48,24 +62,26 @@ class TestVisibilitiesAPI:
         visibilities = aa.Visibilities.ones(shape_1d=(2,))
 
         assert type(visibilities) == vis.Visibilities
-        assert (visibilities.in_1d == np.array([[1.0, 1.0], [1.0, 1.0]])).all()
+        print(visibilities)
+        print(visibilities.in_1d)
+        assert (visibilities.in_1d == np.array([1.0 + 1.0j, 1.0 + 1.0j])).all()
 
         visibilities = aa.Visibilities.full(fill_value=2.0, shape_1d=(2,))
 
         assert type(visibilities) == vis.Visibilities
-        assert (visibilities.in_1d == np.array([[2.0, 2.0], [2.0, 2.0]])).all()
+        assert (visibilities.in_1d == np.array([2.0 + 2.0j, 2.0 + 2.0j])).all()
 
     def test__ones_zeros__makes_visibilities_without_other_inputs(self):
 
         visibilities = aa.Visibilities.ones(shape_1d=(2,))
 
         assert type(visibilities) == vis.Visibilities
-        assert (visibilities.in_1d == np.array([[1.0, 1.0], [1.0, 1.0]])).all()
+        assert (visibilities.in_1d == np.array([1.0 + 1.0j, 1.0 + 1.0j])).all()
 
         visibilities = aa.Visibilities.zeros(shape_1d=(2,))
 
         assert type(visibilities) == vis.Visibilities
-        assert (visibilities.in_1d == np.array([[0.0, 0.0], [0.0, 0.0]])).all()
+        assert (visibilities.in_1d == np.array([0.0 + 0.0j, 0.0 + 0.0j])).all()
 
     def test__from_fits__makes_visibilities_without_other_inputs(self):
 
@@ -74,14 +90,18 @@ class TestVisibilitiesAPI:
         )
 
         assert type(visibilities) == vis.Visibilities
-        assert (visibilities.in_1d == np.ones((3, 2))).all()
+        assert (
+            visibilities.in_1d == np.array([1.0 + 1.0j, 1.0 + 1.0j, 1.0 + 1.0j])
+        ).all()
 
         visibilities = aa.Visibilities.from_fits(
             file_path=path.join(test_data_dir, "3x2_twos.fits"), hdu=0
         )
 
         assert type(visibilities) == vis.Visibilities
-        assert (visibilities.in_1d == 2.0 * np.ones((3, 2))).all()
+        assert (
+            visibilities.in_1d == np.array([2.0 + 2.0j, 2.0 + 2.0j, 2.0 + 2.0j])
+        ).all()
 
 
 class TestVisibilities:
@@ -105,8 +125,9 @@ class TestVisibilities:
         visibilities_from_out = aa.Visibilities.from_fits(
             file_path=path.join(output_data_dir, "visibilities.fits"), hdu=0
         )
-
-        assert (visibilities_from_out.in_1d == np.ones((3, 2))).all()
+        assert (
+            visibilities.in_1d == np.array([1.0 + 1.0j, 1.0 + 1.0j, 1.0 + 1.0j])
+        ).all()
 
 
 class TestVisibilitiesNoiseMap:
@@ -117,23 +138,34 @@ class TestVisibilitiesNoiseMap:
         )
 
         assert type(noise_map) == vis.VisibilitiesNoiseMap
-        assert noise_map.in_1d_flipped == np.array([[2.0, 1.0], [4.0, 3.0]])
-        assert (noise_map.in_1d == np.array([[1.0, 2.0], [3.0, 4.0]])).all()
-        assert (noise_map.real == np.array([1.0, 3.0])).all()
-        assert (noise_map.imag == np.array([2.0, 4.0])).all()
-        assert (noise_map.as_complex == np.array([[1.0 + 2.0j], [3.0 + 4.0j]])).all()
+        assert (noise_map.in_1d == np.array([1.0 + 2.0j, 3.0 + 4.0j])).all()
         assert (noise_map.amplitudes == np.array([np.sqrt(5), 5.0])).all()
         assert noise_map.phases == pytest.approx(
             np.array([1.10714872, 0.92729522]), 1.0e-4
         )
-        assert noise_map.preconditioner_noise_normalization == pytest.approx(
-            1.4236, 1.0e-4
+
+        noise_map = aa.VisibilitiesNoiseMap.manual_1d(
+            visibilities=[[1.0, 1.0], [2.0, 2.0], [2.0, 4.0]]
         )
+
+        assert (
+            noise_map.Wop.todense()
+            == np.array(
+                [
+                    [1.0 + 0.0j, 0.0 + 0.0j, 0.0 + 0.0j],
+                    [0.0 + 0.0j, 0.5 + 0.0j, 0.0 + 0.0j],
+                    [0.0 + 0.0j, 0.0 + 0.0j, 0.5 + 0.0j],
+                ]
+            )
+        ).all()
+
         # assert (
         #     noise_map.Wop.todense()
-        #     == np.array([[0.2 - 0.4j, 0.0 + 0.0j], [0.0 + 0.0j, 0.12 - 0.16j]])
+        #     == np.array(
+        #         [
+        #             [1.0 + 1.0j, 0.0 + 0.0j, 0.0 + 0.0j],
+        #             [0.0 + 0.0j, 0.5 + 0.5j, 0.0 + 0.0j],
+        #             [0.0 + 0.0j, 0.0 + 0.0j, 0.5 + 0.25j],
+        #         ]
+        #     )
         # ).all()
-
-        assert noise_map.Wop.todense() == pytest.approx(
-            np.array([[1.0, 0.0], [0.0, 0.33333]]), 1.0e-4
-        )
